#!/bin/bash

# DevBox Email Collection API - Simple Startup Script

echo "🚀 Starting DevBox Email Collection API..."

# Check if Python 3 is available
if ! command -v python3 &> /dev/null; then
    echo "❌ Error: python3 not found"
    echo "Please install Python 3"
    exit 1
fi

echo "✅ Found Python: $(python3 --version)"

# Create virtual environment if it doesn't exist
if [ ! -d "venv" ]; then
    echo "📦 Creating virtual environment..."
    python3 -m venv venv
fi

# Activate virtual environment
echo "🔧 Activating virtual environment..."
source venv/bin/activate

# Install dependencies directly (simpler approach)
echo "📚 Installing dependencies..."
pip install --upgrade pip
pip install fastapi uvicorn[standard] pydantic[email] python-multipart

echo ""
echo "🎉 Setup complete!"
echo "📍 API will be available at: http://localhost:8000"
echo "📖 API documentation at: http://localhost:8000/docs"
echo ""
echo "🚀 Starting server..."
echo "💡 Press Ctrl+C to stop"
echo ""

# Start the application
python main.py --dev